<?php
/* --------------------------------------------------------------
  OrderAjaxHandler.inc.php 2014-08-07 tb@gambio
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2014 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------
 */

require_once(DIR_FS_CATALOG . 'gm/classes/JSON.php');

class OrderAjaxHandler extends AjaxHandler
{
	function get_permission_status($p_customers_id = NULL)
	{
		if($_SESSION['customers_status']['customers_status_id'] === '0')
		{
			#admins only
			return true;
		}
		return false;
	}

	function proceed()
	{
		$t_output_array = array();
		$t_enable_json_output = true;

		$t_action_request = $this->v_data_array['GET']['action'];
		
		$coo_language_text_manager = MainFactory::create_object('LanguageTextManager', array('lang/' . $_SESSION['language'] . '/admin/orders.php', $_SESSION['languages_id']));

		switch($t_action_request)
		{
			case 'download_pdf':
				$t_type = trim(basename($_GET['type']));
				$t_file = trim(basename($_GET['file']));
				if($t_type != '' && $t_file != '' && file_exists(DIR_FS_CATALOG . 'export/' . $t_type . '/' . $t_file))
				{
					$t_file_parts = explode('__', $t_file);
					
					if($t_type == 'invoice')
					{
						$t_file_name = $coo_language_text_manager->get_text('ADMIN_INVOICE_PDF_NAME');
						$t_file_name = str_replace('{ORDER_ID}', $t_file_parts[0], $t_file_name);
						$t_file_name = str_replace('{INVOICE_ID}', $t_file_parts[1], $t_file_name);
						$t_file_name = str_replace('{DATE}', $t_file_parts[2], $t_file_name);
						$t_file_name = xtc_cleanName($t_file_name, '_');
					}
					elseif($t_type == 'packingslip')
					{
						$t_file_name = $coo_language_text_manager->get_text('ADMIN_PACKINGSLIP_PDF_NAME');
						$t_file_name = str_replace('{ORDER_ID}', $t_file_parts[0], $t_file_name);
						$t_file_name = str_replace('{DATE}', $t_file_parts[1], $t_file_name);
						$t_file_name = xtc_cleanName($t_file_name, '_');
					}
					
					header("Content-Type: application/force-download");
					header("Content-Type: application/octet-stream");
					header('Content-Disposition: attachment; filename="' . $t_file_name . '.pdf"');
					header("Content-Transfer-Encoding: binary");
					header('Expires: 0');
					header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
					header('Pragma: public');
					readfile(DIR_FS_CATALOG . 'export/' . $t_type . '/' . $t_file);
				}
				xtc_db_close();
				exit(0);
				break;
			
			case 'show_pdf':
				$t_type = trim(basename($_GET['type']));
				$t_file = trim(basename($_GET['file']));
				if($t_type != '' && $t_file != '' && file_exists(DIR_FS_CATALOG . 'export/' . $t_type . '/' . $t_file))
				{
					header('Content-type: application/pdf');
					echo file_get_contents(DIR_FS_CATALOG . 'export/' . $t_type . '/' . $t_file);
				}
				xtc_db_close();
				exit(0);
				break;
				
			case 'delete_pdf':
				$t_type = trim(basename($_POST['type']));
				$t_file = trim(basename($_POST['file']));
				if($t_type != '' && $t_file != '' && file_exists(DIR_FS_CATALOG . 'export/' . $t_type . '/' . $t_file))
				{
					@unlink(DIR_FS_CATALOG . 'export/' . $t_type . '/' . $t_file);
				}
				xtc_db_close();
				exit(0);
				break;
			
			case 'quantity_checker':
				$t_enable_json_output = false;
				if(is_numeric(xtc_get_prid($this->v_data_array['GET']['id'])))
				{
					$products_id = xtc_get_prid($this->v_data_array['GET']['id']);
					$qty = gm_convert_qty($this->v_data_array['GET']['qty']);

					$get_products_data = xtc_db_query("SELECT gm_min_order, gm_graduated_qty FROM products WHERE products_id = '" . (int)$products_id . "'");
					if(xtc_db_num_rows($get_products_data) == 1)
					{
						$products_data = xtc_db_fetch_array($get_products_data);
						if(empty($products_data['gm_min_order']))
						{
							$products_data['gm_min_order'] = 1;
						}
						if(empty($products_data['gm_graduated_qty']))
						{
							$products_data['gm_graduated_qty'] = 1;
						}
						if($qty < $products_data['gm_min_order'])
						{
							$this->v_output_buffer .= GM_ORDER_QUANTITY_CHECKER_MIN_ERROR_1 . str_replace('.', ',', (double)$products_data['gm_min_order']) . GM_ORDER_QUANTITY_CHECKER_MIN_ERROR_2;
						}
						$result = $qty / $products_data['gm_graduated_qty'];
						$result = round($result, 4); // workaround for next if-case to avoid calculating failure
						if((int)$result != $result)
						{
							$this->v_output_buffer .= GM_ORDER_QUANTITY_CHECKER_GRADUATED_ERROR_1 . str_replace('.', ',', (double)$products_data['gm_graduated_qty']) . GM_ORDER_QUANTITY_CHECKER_GRADUATED_ERROR_2;
						}
					}
				}
				break;
			default:
				print_r($_GET);
				trigger_error('t_action_request not found: ' . htmlentities($t_action_request));
				return false;
		}

		if($t_enable_json_output)
		{
			$coo_json = new Services_JSON(SERVICES_JSON_LOOSE_TYPE);
			$t_output_json = $coo_json->encode($t_output_array);

			$this->v_output_buffer = $t_output_json;
		}

		return true;
	}
}